==> agent_starter_pack-0.4.1.tar.gz: agent_starter_pack-0.4.1/docs/index.md <==
---
layout: home
title: Home

hero:
  name: Agent Starter Pack
  text: Production-Ready  Agents on Google Cloud, faster
  tagline: Go from idea to deployment faster with pre-built templates & tools.
  image:
    src: https://github.com/GoogleCloudPlatform/agent-starter-pack/blob/main/docs/images/logo.png?raw=true
    alt: Agent Starter Pack Logo
  actions:
    - theme: brand
      text: Get Started Guide
      link: /guide/getting-started
    - theme: alt
      text: Watch Demo Video
      link: https://www.youtube.com/embed/eZ-8UQ_t4YM?start=2791

features:
  - icon: ⚡️
    title: Launch Quickly
    details: Start fast with pre-built agent templates (ReAct, RAG, multi-agent, Live Multimodal API) implementing common patterns.
  - icon: 🧪
    title: Experiment & Evaluate
    details: Iterate using integrated Vertex AI evaluation and an interactive testing playground.
  - icon: ☁️
    title: Deploy Confidently
    details: Ship reliable agents with production-ready infra (Cloud Run / Agent Engine) featuring monitoring, observability, and CI/CD.
  - icon: 🛠️
    title: Customize & Extend
    details: Adapt and enhance templates and infrastructure for your specific use case.
---

::: tip ⭐ Like Agent Starter Pack?
Help us spread the word by giving us a star on GitHub!

<a href="https://github.com/GoogleCloudPlatform/agent-starter-pack/stargazers" target="_blank" rel="noopener noreferrer" style="display: inline-block; margin-top: 8px;"> <!-- Link the badge too! -->
  ![GitHub Stars](https://img.shields.io/github/stars/GoogleCloudPlatform/agent-starter-pack?style=social&color=yellow) <!-- Added style=social for better look -->
</a>
:::

## Quick Links

- **New Users:** [Getting Started Guide](/guide/getting-started)
- **Setup:** [Installation Guide](/guide/installation)
- **Going Live:** [Deployment Guide](/guide/deployment)
- **Explore Templates:** [Agent Templates Overview](/agents/overview)
- **Command Line:** [CLI Reference](/cli/)

==> agent_starter_pack-0.4.3.tar.gz: agent_starter_pack-0.4.3/docs/index.md <==
---
layout: home
title: Home

hero:
  name: Agent Starter Pack
  text: Production-Ready  Agents on Google Cloud, faster
  tagline: Go from idea to deployment faster with pre-built templates & tools.
  image:
    src: https://github.com/GoogleCloudPlatform/agent-starter-pack/blob/main/docs/images/logo.png?raw=true
    alt: Agent Starter Pack Logo
  actions:
    - theme: brand
      text: Get Started Guide
      link: /guide/getting-started
    - theme: alt
      text: Watch Demo Video
      link: https://www.youtube.com/watch?v=9zqwym-N3lg

features:
  - icon: ⚡️
    title: Launch Quickly
    details: Start fast with pre-built agent templates (ReAct, RAG, multi-agent, Live Multimodal API) implementing common patterns.
  - icon: 🧪
    title: Experiment & Evaluate
    details: Iterate using integrated Vertex AI evaluation and an interactive testing playground.
  - icon: ☁️
    title: Deploy Confidently
    details: Ship reliable agents with production-ready infra (Cloud Run / Agent Engine) featuring monitoring, observability, and CI/CD.
  - icon: 🛠️
    title: Customize & Extend
    details: Adapt and enhance templates and infrastructure for your specific use case.
---

::: tip ⭐ Like Agent Starter Pack?
Help us spread the word by giving us a star on GitHub!

<a href="https://github.com/GoogleCloudPlatform/agent-starter-pack/stargazers" target="_blank" rel="noopener noreferrer" style="display: inline-block; margin-top: 8px;"> <!-- Link the badge too! -->
  ![GitHub Stars](https://img.shields.io/github/stars/GoogleCloudPlatform/agent-starter-pack?style=social&color=yellow) <!-- Added style=social for better look -->
</a>

:::

## Quick Links

- **New Users:** [Getting Started Guide](/guide/getting-started)
- **Setup:** [Installation Guide](/guide/installation)
- **Going Live:** [Deployment Guide](/guide/deployment)
- **Explore Templates:** [Agent Templates Overview](/agents/overview)
- **Command Line:** [CLI Reference](/cli/)
